==> pyfora-0.1a5.tar.gz: pyfora-0.1a5/pyfora/NamedSingletons.py <==
#   Copyright 2015 Ufora Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""NamedSingletons

A manifest of python objects that have explicit FORA implementations in the purePython module.
"""

pythonSingletonToName = {
    type: 'type',
    float: 'float',
    int: 'int',
    bool: 'bool',
    str: 'str',
    list: 'list',
    tuple: 'tuple',
    object: 'object',
    dict: 'dict',
    type(None): 'NoneType',
    issubclass: 'issubclass',
    isinstance: 'isinstance',
    Exception: 'Exception',
    UserWarning: 'UserWarning',
    TypeError: 'TypeError',
    ValueError: 'ValueError',
    AttributeError: 'AttributeError',
    ZeroDivisionError: 'ZeroDivisionError',
    ValueError: 'ValueError',
    IndexError: 'IndexError'
    }

singletonNameToObject = {v:k for k,v in pythonSingletonToName.iteritems()}

pythonNameToPyforaName = {
    'type': 'Type',
    'float': 'FloatType',
    'int': 'IntType',
    'bool': 'BoolType',
    'str': 'StrType',
    'list': 'ListType',
    'tuple': 'TupleType',
    'dict': 'DictType',
    'NoneType': 'NoneType',
    'object': 'Object',
    'isinstance': 'IsInstance',
    'issubclass': 'IsSubclass',
    'Exception': 'Exception',
    'TypeError': 'TypeError',
    'ValueError': 'ValueError',
    'UserWarning': 'UserWarning',
    'AttributeError': 'AttributeError',
    'ZeroDivisionError': 'ZeroDivisionError',
    'ValueError': 'ValueError',
    'IndexError': 'IndexError'
    }

==> pyfora-0.2rc1.tar.gz: pyfora-0.2rc1/pyfora/NamedSingletons.py <==
#   Copyright 2015 Ufora Inc.
#
#   Licensed under the Apache License, Version 2.0 (the "License");
#   you may not use this file except in compliance with the License.
#   You may obtain a copy of the License at
#
#       http://www.apache.org/licenses/LICENSE-2.0
#
#   Unless required by applicable law or agreed to in writing, software
#   distributed under the License is distributed on an "AS IS" BASIS,
#   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#   See the License for the specific language governing permissions and
#   limitations under the License.

"""NamedSingletons

A manifest of python objects that have explicit FORA implementations in the purePython module.
"""

pythonSingletonToName = {
    bool: 'bool',
    dict: 'dict',
    float: 'float',
    int: 'int',
    isinstance: 'isinstance',
    issubclass: 'issubclass',
    list: 'list',
    object: 'object',
    slice: 'slice',
    str: 'str',
    tuple: 'tuple',
    type: 'type',
    type(None): 'NoneType',
    AttributeError: 'AttributeError',
    Exception: 'Exception',
    IndexError: 'IndexError',
    TypeError: 'TypeError',
    NotImplementedError: 'NotImplementedError',
    UserWarning: 'UserWarning',
    UnboundLocalError: 'UnboundLocalError',
    ValueError: 'ValueError',
    ZeroDivisionError: 'ZeroDivisionError'
    }

singletonNameToObject = {v:k for k,v in pythonSingletonToName.iteritems()}

pythonNameToPyforaName = {
    'bool': 'BoolType',
    'dict': 'DictType',
    'float': 'FloatType',
    'int': 'IntType',
    'isinstance': 'IsInstance',
    'issubclass': 'IsSubclass',
    'list': 'ListType',
    'object': 'Object',
    'slice': 'SliceType',
    'str': 'StrType',
    'tuple': 'TupleType',
    'type': 'Type',
    'AttributeError': 'AttributeError',
    'Exception': 'Exception',
    'IndexError': 'IndexError',
    'NoneType': 'NoneType',
    'NotImplementedError': 'NotImplementedError',
    'TypeError': 'TypeError',
    'UserWarning': 'UserWarning',
    'UnboundLocalError': 'UnboundLocalError',
    'ValueError': 'ValueError',
    'ZeroDivisionError': 'ZeroDivisionError'
    }
